@@ -279,7 +279,7 @@
 #define HAVE_WCHAR_T 1
 #define HAVE_WINT_T 1
 #define HAVE_CURSES_H 1
-/* #undef HAVE_NCURSES_H */
+#define HAVE_NCURSES_H 1
 #define USE_LIBEDIT_INTERFACE 1
 #define HAVE_HIST_ENTRY 1
 #define USE_NEW_EDITLINE_INTERFACE 1
@@ -404,14 +404,14 @@
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
 #define MYSQL_VERSION_PATCH 37
-#define MYSQL_VERSION_EXTRA "-ndb-7.5.25"
+#define MYSQL_VERSION_EXTRA "-ndb-7.6.21"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.37-ndb-7.5.25"
+#define PACKAGE_STRING "MySQL Server 5.7.37-ndb-7.6.21"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.37-ndb-7.5.25"
-#define VERSION "5.7.37-ndb-7.5.25"
+#define PACKAGE_VERSION "5.7.37-ndb-7.6.21"
+#define VERSION "5.7.37-ndb-7.6.21"
 #define PROTOCOL_VERSION 10
 
 /*
